<?php

namespace Ems\portalGestor\Service;

use Zeedhi\Framework\Controller\Crud;
use Doctrine\ORM\EntityManager;
use Ems\portalGestor\Util\HcmServices;

use Ems\portalGestor\Util\DateUtil;

class LancamentoService extends Crud {
    /** @var HcmServices $hcmServices */
    public $hcmSevices;

    public function __construct(
        HcmServices $hcmServices
    ) {

        $this->hcmServices = $hcmServices;
    }

    public function getLotesLancamento(
        int $nrOrg,
        string $cdOperador,
        int $nrPeriodo
    ) {

        $hcmServicesRoute = 'getLotesLancamento';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'CDOPERADOR' => $cdOperador,
                'NRPERIODOAPURACAO' => $nrPeriodo
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $lotes = $response['dataset']['getLotesLancamento'];

        return $lotes;
    }

    public function getLancamentosEvento(
        int $nrOrg,
        int $nrLote,
        int $nrEstrutura,
        int $nrPeriodo
    ): array {

        $hcmServicesRoute = 'getLancamentosEvento';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRLOTELANCEVENTO'  => $nrLote,
                'NRPERIODOAPURACAO' => $nrPeriodo,
                'NRESTRUTURAM'      => $nrEstrutura
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $lotes = $response['dataset']['getLancamentosEvento'];

        return $lotes;
    }

    public function getTiposMovimento(
        int $nrOrg
    ): array{

        $hcmServicesRoute = 'getTiposMovimento';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'empty' => true
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $tiposMov = $response['dataset'][$hcmServicesRoute];

        return $tiposMov;
    }

    public function insertLoteLancamento(
        int $nrOrg,
        string $dsLote,
        string $dtOcorrencia,
        string $dtCompetencia,
        string $cdOperador,
        int $nrTipoMov
    ) {

        $hcmServicesRoute = 'insertLoteLancamento';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'CDOPERADOR'       => $cdOperador,
                'DSLOTELANCEVENTO' => $dsLote,
                'DTOCORRENCIA'     => $dtOcorrencia,
                'DTCOMPETLOTEEVE'  => $dtCompetencia,
                'NRTIPOMOVIMENT'   => $nrTipoMov
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $success = $response['dataset'][$hcmServicesRoute]['success'];

        return $success;
    }

    public function getEventosLancamento(
        int $nrOrg,
        int $nrEstrutura
    ): array {

        $hcmServicesRoute = 'getEventosLancamento';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRESTRUTURAM'      => $nrEstrutura
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $eventos = $response['dataset'][$hcmServicesRoute];

        return $eventos;
    }

    public function editLoteLancamento(
        int $nrOrg,
        int $nrLote,
        string $dsLote,
        string $dtOcorrencia,
        string $dtCompetencia,
        string $cdOperador,
        int $nrTipoMov
    ) {

        $hcmServicesRoute = 'editLoteLancamento';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRLOTELANCEVENTO' => $nrLote,
                'CDOPERADOR'       => $cdOperador,
                'DSLOTELANCEVENTO' => $dsLote,
                'DTOCORRENCIA'     => $dtOcorrencia,
                'DTCOMPETLOTEEVE'  => $dtCompetencia,
                'NRTIPOMOVIMENT'   => $nrTipoMov
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $success = $response['dataset'][$hcmServicesRoute]['success'];

        return $success;
    }

    public function confirmLoteLancamento(
        int $nrOrg,
        int $nrLote
    ) {

        $hcmServicesRoute = 'confirmLoteLancamento';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRLOTELANCEVENTO' => $nrLote
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $success = $response['dataset'][$hcmServicesRoute]['success'];

        return $success;
    }

    public function editLancamentos(
        int $nrOrg,
        array $lancamentos,
        string $cdOperador
    ) {

        $hcmServicesRoute = 'editLancamentos';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'lancamentos' => $lancamentos,
                'CDOPERADOR'  => $cdOperador
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $success = $response['dataset'][$hcmServicesRoute]['success'];

        return $success;
    }

    public function deleteLoteLancamento(
        int $nrOrg,
        int $nrLote
    ) {

        $hcmServicesRoute = 'deleteLoteLancamento';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRLOTELANCEVENTO'  => $nrLote
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $success = $response['dataset'][$hcmServicesRoute]['success'];

        return $success;
    }
}
